<template>
  <div class="whiteContent Content">
    <div class="title" v-show="false">设备地图</div>

    <!-- 全屏按钮 -->
    <img
      class="zoomOut iconfont"
      src="/images/equipmentManagement/full.png"
      @click="toggleZoom('Full')"
      v-show="false"
    />
    <!-- 取消全屏的按钮 -->
    <img class="zoomOut iconfont" src="/images/equipmentManagement/quit.png" @click="toggleZoom('')" v-show="false" />

    <!-- 普通地图  v-show="false" -->
    <div class="map-box">
      <div class="map-txt">设备地图</div>
      <div id="map"></div>
    </div>
    <!-- 全屏地图 -->
    <div id="mapFull" v-show="false"></div>
    <InfoCard @close="closeCard" v-if="isShowCard" :node="activeNode"></InfoCard>
    <FormList v-if="!isFull"></FormList>
  </div>
</template>

<script>
import { findDevList } from "@/api/device"
import AMapLoader from "@amap/amap-jsapi-loader"
import InfoCard from "@/views/equipmentManagement/equipmentList/components/InfoCard"
import FormList from "@/views/equipmentManagement/equipmentList/components/FormList"

import bus from "@/plugin/bus"

export default {
  created() {
    window._AMapSecurityConfig = {
      securityJsCode: "768ab79bdc4075aa082bc070c53bb3c4"
    }
  },
  mounted() {
    this.initMap("")
    bus.$on("refleshNode", (node) => {
      this.nodes = node
      this.initNode()
    })
  },
  beforeDestroy() {
    bus.$off("refleshNode")
  },

  components: {
    InfoCard, //设备信息弹层
    FormList //表格
  },
  data() {
    return {
      map: null,
      AMap: null,
      nodes: [],
      isShowCard: false,
      isFull: false, //是否全屏
      zoom: 4, //地图级别
      center: [116.06157, 39.66157], //地图中心
      activeNode: null, //选中的地图节点
      geocoder: {},
      myMaker: null
    }
  },

  methods: {
    //初始化地图
    initMap(status) {
      AMapLoader.load({
        key: "69cd7e958683e8462beab5c08e6bc21b", // 申请好的Web端开发者Key，首次调用 load 时必填
        version: "2.0", // 指定要加载的 JSAPI 的版本，缺省时默认为 1.4.15
        plugins: ["AMap.Geocoder", "AMap.Geolocation"] // 需要使用的的插件列表，如比例尺'AMap.Scale'等
      })
        .then((AMap) => {
          this.AMap = AMap
          this.map = new AMap.Map(`map${status}`, {
            //设置地图容器id
            zoom: this.zoom, //初始化地图级别
            center: this.center, //初始化地图中心点位置
            mapStyle: "amap://styles/macaron" // macaron  whitesmoke
          })

          //初始化查询地理位置插件
          AMap.plugin("AMap.Geocoder", () => {
            this.geocoder = new AMap.Geocoder()
          })

          this.initNode()
        })
        .catch((e) => {
          console.log(e)
        })
    },
    //初始化节点
    initNode() {
      if (this.myMaker) {
        this.myMaker.destroy()
      }
      this.nodes.filter((item, index) => {
        //查询行政位置
        this.geocoder.getAddress([item.lon, item.lat], (status, result) => {
          // 节点坐标
          let position = new this.AMap.LngLat(item.lon, item.lat)
          // 节点地理位置
          item.province = result.regeocode.addressComponent.province

          //信息框dom
          let markerContent =
            "" +
            `<div class="nodeMarker" id="node${index}}">` +
            '<img class="normal" src="/images/equipmentManagement/default.png">' +
            '<img class="selected" src="/images/equipmentManagement/select.png">' +
            `<div class="box"><div class="box-triangle"></div> <div class=box-txt"> <div class="name">${item.devName}</div> <div class="property">IP地址: <span class="data">${item.devIp}</span> </div> <div class="property">设备位置: <span class="data">${item.province}</span></div><div class="property">安装时间: <span class="data">${item.installTime}</span></div></div></div>`
          ;("</div>")

          let marker = new this.AMap.Marker({
            position: position,
            // 将 html 传给 content
            content: markerContent,
            // 以 icon 的 [center bottom] 为原点
            offset: new this.AMap.Pixel(-24, -24)
          })

          //给节点添加的监听
          marker.on("click", () => {
            this.activeNode = item
            this.isShowCard = true
          })

          this.map.add(marker)
          this.myMaker = marker
        })
      })
    },
    //关闭设备详情弹层
    closeCard() {
      this.isShowCard = false
    },
    //切换全屏地图
    toggleZoom(status) {
      //获取当前地图级别
      this.zoom = this.map.getZoom()
      //获取当前地图中心位置
      let data = this.map.getCenter()
      this.center = [data.lng, data.lat]
      if (status) {
        this.isFull = true
      } else {
        this.isFull = false
      }
      this.initMap(status)
    }
  }
}
</script>

<style scoped lang="scss">
.whiteContent {
  position: relative;
  box-sizing: border-box;
  // padding: 20px;
  width: 95%;
  min-width: 1280px;
  // background-color: #34405a;
  margin: 0 auto;

  .title {
    margin-bottom: 10px;
    font-weight: bold;
    font-size: 16px;
  }
  .map-box {
    background-color: #1f2a3e;
    border-radius: 18px;
    // width: 100%;
    padding: 24px;
    margin-bottom: 24px;
    .map-txt {
      font-family: PingFang SC Heavy;
      font-size: 16px;
      font-weight: normal;
      line-height: 24px;
      letter-spacing: 0px;
      color: #ffffff;
      margin-bottom: 16px;
    }
    #map,
    #mapFull {
      width: 100%;
      // height: 496px;
      min-height: 496px;
      height: 60vh;
      border-radius: 8px;

      ::v-deep .nodeMarker {
        position: relative;
        .selected {
          display: none;
        }
        .box-triangle {
          // box-sizing: border-box;
          // display: none;
          // position: absolute;
          position: absolute;
          top: -15px;
          left: 115px;

          height: 0px;
          width: 0px;
          // background: red;
          border-bottom: 8px solid #ffffff;
          border-top: 8px solid transparent;
          border-left: 8px solid transparent;
          border-right: 8px solid transparent;
        }

        .box {
          box-sizing: border-box;
          display: none;
          position: absolute;
          padding: 20px 10px;
          top: 66px;
          left: -100px;
          width: 247px;
          height: 160px;
          background-color: rgba($color: #fff, $alpha: 0.8);
          filter: drop-shadow(0px 2px 16px rgba(0, 43, 106, 0.25));

          .name {
            opacity: 1;
            font-family: PingFangSC-Bold;
            font-size: 16px;
            font-weight: normal;
            line-height: 24px;
            letter-spacing: 0px;
            color: #3d3d3d;

            margin-bottom: 14px;
          }

          .property {
            margin-bottom: 12px;
            font-size: 14px;
            color: #999;

            span {
              margin-left: 5px;
              color: #3d3d3d;
              font-weight: 700;
            }

            &:last-child {
              margin-bottom: 0;
            }
          }
        }

        &:hover {
          .normal {
            display: none;
          }

          .selected {
            position: relative;
            top: -16px;
            left: -16px;
            display: inline-block;
          }

          .box {
            display: inline-block;
          }
        }
      }
    }
  }

  #mapFull {
    height: 872px;
  }

  .InfoCard {
    position: absolute;
    top: 68px;
    right: 28px;
    z-index: 2;
  }

  .zoomOut {
    position: absolute;
    z-index: 2;
    top: 74px;
    left: 40px;
    width: 32px;
    cursor: pointer;
  }
}
</style>
